package com.qadeer.customer.controller;

import com.qadeer.customer.dto.CustomerDto;
import com.qadeer.customer.dto.ProductDto;
import com.qadeer.customer.dto.CustomerRequest;
import com.qadeer.customer.model.Customer;
import com.qadeer.customer.service.CustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("/customer")
public class CustomerController {

    @Autowired
    private CustomerService service;

    @GetMapping("/hello")
    public String hello() {
        return "Hello";
    }

    @GetMapping("/buy/{productName}/{quantity}")
    public ResponseEntity<List<ProductDto>> buy(@PathVariable("productName") String productName, @PathVariable("quantity") int productQuantity) {
        List<ProductDto> productDtoList = service.buyProductByName(productName, String.valueOf(productQuantity));
        return new ResponseEntity<List<ProductDto>>(productDtoList, HttpStatus.OK);
    }

    // current
    @PostMapping("product/buy/json")
    public ResponseEntity<?> buyJson(@RequestBody @Valid CustomerRequest customerRequest) {
        List<ProductDto> products = customerRequest.getItems();
        CustomerDto customerDto = customerRequest.getCustomerDto();
        System.out.println(customerDto.toString());
//        for(ProductDto p : products) {
//            System.out.println(p.getName() + " " + p.getQuantity());
//        }
        List<ProductDto> availableProducts = service.buyProducts(customerRequest);

        return new ResponseEntity<>(availableProducts, HttpStatus.OK);
    }

    @GetMapping("/product/{id}")
    public ResponseEntity<?> getProductById(@PathVariable int id) {
        ProductDto productDto = service.getProductById(id);
        return ResponseEntity.ok(productDto);
    }
}
