package com.qadeer.inventory.controller;

import com.qadeer.inventory.dto.CustomerDto;
import com.qadeer.inventory.dto.CustomerRequest;
import com.qadeer.inventory.model.Product;
import com.qadeer.inventory.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/inventory")
public class InventoryController {

    @Autowired
    private ProductService service;

    @GetMapping("/hello")
    public String hello() {
        return "Hello";
    }

    @PostMapping("/restock")
    public ResponseEntity<?> restock(MultipartFile file) throws IOException {
        List< Product> productList = service.restock(file);
        return new ResponseEntity<List<Product>>(productList, HttpStatus.OK);
    }

    @GetMapping("/product/{id}")
    public ResponseEntity<?> getProductById(@PathVariable int id) {
        Product product = service.getProductById(id);
        return new ResponseEntity<Product>(product, HttpStatus.OK);
    }

    @GetMapping("/product/{productName}/{productQuantity}")
    public ResponseEntity<?> buyProductByName(@PathVariable("productName") String productName, @PathVariable("productQuantity") int productQuantity) {
        Product product = service.buyProductByName(productName, productQuantity);
        return new ResponseEntity<>(product, HttpStatus.OK);
    }

    @PostMapping("/product/buy/json")
    public ResponseEntity<?> buyProducts(@RequestBody CustomerRequest customerRequest) {
        List<Product> requestedProducts = service.buyProducts(customerRequest);
        return new ResponseEntity<>(requestedProducts, HttpStatus.OK);
    }
}
