package com.qadeer.inventory.service;

import com.qadeer.inventory.dto.CustomerRequest;
import com.qadeer.inventory.model.Product;
import com.qadeer.inventory.repository.ProductRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

@Service
public class ProductService {

    @Autowired
    private ProductRepository repository;

    public List<Product> getAllProducts() {
        return repository.findAll();
    }

    public Product getProductById(int id) {
        return repository.findById(id).get();
    }

    public void createProduct(Product product) {
        repository.save(product);
    }

    public List<Product> restock(MultipartFile file) throws IOException {
        InputStreamReader ir = new InputStreamReader(file.getInputStream());
        BufferedReader br = new BufferedReader(ir);
        String line = br.readLine();
        line = br.readLine();
        List<Product> productList = new ArrayList<>();
        while (line != null) {
            String[] content = line.split(",");
            String name = content[0].trim();
            int price = Integer.parseInt(content[1]);
            int quantity = Integer.parseInt(content[2]);
            Product product = new Product(name, price, quantity);
            repository.save(product);
            productList.add(product);
            line = br.readLine();
        }
        return productList;
    }

    public Product buyProductByName(String productName, int requiredQuantity) {
        Product product = repository.findByName(productName);
        int restockQuantity = 0;
        Product productRequested = new Product();
        if (product.getQuantity() >= requiredQuantity) {
            // create copy of product object.
            productRequested.setId(product.getId());
            productRequested.setName(product.getName());
            productRequested.setPrice(product.getPrice());
            productRequested.setQuantity(requiredQuantity);
            product.setQuantity(product.getQuantity() - requiredQuantity);
            repository.save(product);
        }
        else if (product.getQuantity() > 0 && product.getQuantity() < requiredQuantity){
            restockQuantity = requiredQuantity - product.getQuantity();
            // create copy of product object.
            productRequested.setId(product.getId());
            productRequested.setName(product.getName());
            productRequested.setPrice(product.getPrice());
            productRequested.setQuantity(product.getQuantity());
            product.setQuantity(0);
            repository.save(product);
        }

        return productRequested;
    }

    public List<Product> buyProducts(CustomerRequest customerRequest) {
        List<Product> productDtoList = customerRequest.getItems();
        System.out.println(customerRequest);
        List<Product> requestedProducts = new ArrayList<>();
        for (Product p : productDtoList) {
            Product product = buyProductByName(p.getName(), p.getQuantity());
            requestedProducts.add(product);
        }
        return requestedProducts;
    }

}
